pyparsing.ParseElementEnhance

Module pyparsing :: Class ParseElementEnhance |
[frames] | no frames]

# Class ParseElementEnhance

source code

       object --+
                |
    ParserElement --+
                    |
                   ParseElementEnhance

Known Subclasses:
  - TokenConverter
  - , FollowedBy
  - , Forward
  - , NotAny
  - , OneOrMore
  - , Optional
  - , SkipTo
  - , ZeroOrMore

Abstract subclass of `ParserElement`, for combining and post-processing parsed tokens.

Nested Classes
Inherited from `ParserElement`: `literalStringClass`

Instance Methods
__init__(self, expr, savelist=False) x.__init__(...) initializes x; see help(type(x)) for signature | source code
parseImpl(self, instring, loc, doActions=True) | source code
leaveWhitespace(self) Disables the skipping of whitespace before matching the characters in the `ParserElement`'s defined pattern. | source code
ignore(self, other) Define expression to be ignored (e.g., comments) while doing pattern matching; may be called repeatedly, to define multiple comment or other ignorable patterns. | source code
streamline(self) | source code
checkRecursion(self, parseElementList) | source code
validate(self, validateTrace=`[``]`) Check defined expressions for valid structure, check for infinite recursive definitions. | source code
__str__(self) str(x) | source code
Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__eq__`, `__hash__`, `__invert__`, `__mul__`, `__ne__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__req__`, `__rmul__`, `__rne__`, `__ror__`, `__rsub__`, `__rxor__`, `__sub__`, `__xor__`, `addCondition`, `addParseAction`, `copy`, `parseFile`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `runTests`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setFailAction`, `setName`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `suppress`, `transformString`, `tryParse` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `ParserElement`: `enablePackrat`, `inlineLiteralsUsing`, `resetCache`, `setDefaultWhitespaceChars`

Class Variables
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`, `verbose_stacktrace`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, expr, savelist=False) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### parseImpl(self, instring, loc, doActions=True) | source code
Overrides: ParserElement.parseImpl

### leaveWhitespace(self) | source code
Disables the skipping of whitespace before matching the characters in the `ParserElement`'s defined pattern. This is normally only used internally by the pyparsing module, but may be needed in some whitespace-sensitive grammars. Overrides: ParserElement.leaveWhitespace (inherited documentation)

### ignore(self, other) | source code
Define expression to be ignored (e.g., comments) while doing pattern matching; may be called repeatedly, to define multiple comment or other ignorable patterns. Overrides: ParserElement.ignore (inherited documentation)

### streamline(self) | source code
Overrides: ParserElement.streamline

### checkRecursion(self, parseElementList) | source code
Overrides: ParserElement.checkRecursion

### validate(self, validateTrace=`[``]`) | source code
Check defined expressions for valid structure, check for infinite recursive definitions. Overrides: ParserElement.validate (inherited documentation)

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)